"""
Tenable OT Security base package
=======================

This package covers the Tenable OT Security interface.

.. autoclass:: TenableOT
    :members:


.. toctree::
    :hidden:
    :glob:

    assets
    events
    plugins
"""

from .session import TenableOT
